import request from '@/utils/request'
// 班组表单列表查询
export function queryTeamList() {
    return request({
      url: '/system/team/queryTeamList',
      method: 'post',
    })
  }
//新增班组
export function teamAdd(data) {
    return request({
      url: '/system/team/add',
      method: 'post',
      data,
    })
  }
//编辑班组 提交
export function update(data) {
  return request({
    url: '/system/team/update ',
    method: 'post',
    data,
  })
}
// 获取班长人员列表
export function queryTeamUserList() {
    return request({
      url: '/sf/teamUser/queryTeamUserList',
      method: 'post',
    })
  }
//获取人员配置列表
export function queryUserList(data) {
    return request({
      url: '/sf/teamUser/queryUserList',
      method: 'post',
      data
    })
  }
//删除某一行
export function deleteTeam(id) {
    return request({
      url: `/system/team/${id}`,
      method: 'get',
    })
  }
//人员配置确认操作
export function staffingAdd(data) {
  return request({
    url: `/sf/teamUser/add`,
    method: 'post',
    data
  })
}